# Changelog

### [0.2.1](https://www.github.com/bihealth/clinvar-this/compare/v0.2.0...v0.2.1) (2023-03-17)


### Bug Fixes

* fixing strucvar export ([#84](https://www.github.com/bihealth/clinvar-this/issues/84)) ([1050a67](https://www.github.com/bihealth/clinvar-this/commit/1050a67edff50150da955f0e5364148c82b46902))
* sequence variant export ([#82](https://www.github.com/bihealth/clinvar-this/issues/82)) ([0fe3fb9](https://www.github.com/bihealth/clinvar-this/commit/0fe3fb9b4ec783218a408926007bb7370c70be64))

## [0.2.0](https://www.github.com/bihealth/clinvar-this/compare/v0.1.0...v0.2.0) (2023-03-15)


### Features

* add support for SV TSV files ([#75](https://www.github.com/bihealth/clinvar-this/issues/75)) ([#78](https://www.github.com/bihealth/clinvar-this/issues/78)) ([d4fffce](https://www.github.com/bihealth/clinvar-this/commit/d4fffce3772ed33c9d12c81b983e3e152f0c2d83))


### Documentation

* add badges to readme ([#65](https://www.github.com/bihealth/clinvar-this/issues/65)) ([207038c](https://www.github.com/bihealth/clinvar-this/commit/207038ccfa2473e09f283903e9c2a3cd249e2f30))
* adding file format documentation ([#71](https://www.github.com/bihealth/clinvar-this/issues/71)) ([3a04ffd](https://www.github.com/bihealth/clinvar-this/commit/3a04ffddd50ab21c52d3d2fe281d96ac30c505cb))
* extending docs; getting started from README ([#44](https://www.github.com/bihealth/clinvar-this/issues/44)) ([#68](https://www.github.com/bihealth/clinvar-this/issues/68)) ([77892f0](https://www.github.com/bihealth/clinvar-this/commit/77892f0fdaf158ed77c126f0aae11b12457c6043))
* updating docs introduction section ([#67](https://www.github.com/bihealth/clinvar-this/issues/67)) ([d6c865b](https://www.github.com/bihealth/clinvar-this/commit/d6c865b28db14e217c839239940bf9fe4fdcd5ed))

## 0.1.0 (2022-12-02)


### Features

* add basic config management in CLI ([#32](https://www.github.com/bihealth/clinvar-this/issues/32)) ([#33](https://www.github.com/bihealth/clinvar-this/issues/33)) ([c903546](https://www.github.com/bihealth/clinvar-this/commit/c903546751fe6c59fcc20770b6a1ad1ac88fbd86))
* add functions for managing batch data ([#34](https://www.github.com/bihealth/clinvar-this/issues/34), [#37](https://www.github.com/bihealth/clinvar-this/issues/37)) ([#35](https://www.github.com/bihealth/clinvar-this/issues/35)) ([0c7e0f9](https://www.github.com/bihealth/clinvar-this/commit/0c7e0f9b65dc0b2189c302065cdebdc2489ea842))
* add sphinx-based documentation ([#30](https://www.github.com/bihealth/clinvar-this/issues/30)) ([#31](https://www.github.com/bihealth/clinvar-this/issues/31)) ([d10adc5](https://www.github.com/bihealth/clinvar-this/commit/d10adc50a720548b580b7aa6bd52477012bb6d29))
* add tests for submission messages ([#19](https://www.github.com/bihealth/clinvar-this/issues/19)) ([#22](https://www.github.com/bihealth/clinvar-this/issues/22)) ([b168d47](https://www.github.com/bihealth/clinvar-this/commit/b168d47e0b3aed8d3a706ddbd28ddbb635ad86b4))
* add unit tests for submission messages ([#19](https://www.github.com/bihealth/clinvar-this/issues/19)) ([#20](https://www.github.com/bihealth/clinvar-this/issues/20)) ([1c4e11a](https://www.github.com/bihealth/clinvar-this/commit/1c4e11aa6eda5ebce0a66e8f21f17ea89c7ed7e2))
* adding mypy type checking ([#11](https://www.github.com/bihealth/clinvar-this/issues/11)) ([#12](https://www.github.com/bihealth/clinvar-this/issues/12)) ([700994a](https://www.github.com/bihealth/clinvar-this/commit/700994a113f2441bba76e3dc95adccf9fed6a156))
* adjust to ClinVar API change (Nov 2022) ([#47](https://www.github.com/bihealth/clinvar-this/issues/47)) ([#48](https://www.github.com/bihealth/clinvar-this/issues/48)) ([0e4fb50](https://www.github.com/bihealth/clinvar-this/commit/0e4fb508bda571c0c0afdab417e9052667f46ea1))
* allow annotation with HPO terms in TSV format ([#50](https://www.github.com/bihealth/clinvar-this/issues/50)) ([#56](https://www.github.com/bihealth/clinvar-this/issues/56)) ([0b0da41](https://www.github.com/bihealth/clinvar-this/commit/0b0da41e938e464e97ea1be7edcad6c666860f1e))
* allow import of extra columns ([#53](https://www.github.com/bihealth/clinvar-this/issues/53)) ([#54](https://www.github.com/bihealth/clinvar-this/issues/54)) ([616bfe7](https://www.github.com/bihealth/clinvar-this/commit/616bfe7867fe7ddd1c898f7582b1a353069b7ccd))
* completing enums ([#23](https://www.github.com/bihealth/clinvar-this/issues/23)) ([#24](https://www.github.com/bihealth/clinvar-this/issues/24)) ([9198983](https://www.github.com/bihealth/clinvar-this/commit/919898305a6155408118cd43a982c78153976879))
* implement api models ([#4](https://www.github.com/bihealth/clinvar-this/issues/4)) ([#5](https://www.github.com/bihealth/clinvar-this/issues/5)) ([3690c36](https://www.github.com/bihealth/clinvar-this/commit/3690c36b25fc98e520a401f8755a48b3451a972f))
* implement attrs-based message models ([#1](https://www.github.com/bihealth/clinvar-this/issues/1)) ([#2](https://www.github.com/bihealth/clinvar-this/issues/2)) ([f253c24](https://www.github.com/bihealth/clinvar-this/commit/f253c248cf35f749ace3c68633eb8d0357349688))
* implement enums for submission messages ([#14](https://www.github.com/bihealth/clinvar-this/issues/14)) ([#16](https://www.github.com/bihealth/clinvar-this/issues/16)) ([201cbe4](https://www.github.com/bihealth/clinvar-this/commit/201cbe4e055e0d013efe6f85a91b5ec339c77838))
* implement internal models for submissions ([#9](https://www.github.com/bihealth/clinvar-this/issues/9)) ([#26](https://www.github.com/bihealth/clinvar-this/issues/26)) ([be04e40](https://www.github.com/bihealth/clinvar-this/commit/be04e40e15adba180827fdc808c17d7d1647edb7))
* implement minimal TSV format ([#17](https://www.github.com/bihealth/clinvar-this/issues/17)) ([#18](https://www.github.com/bihealth/clinvar-this/issues/18)) ([960827d](https://www.github.com/bihealth/clinvar-this/commit/960827d9be757e5cc1cfe537451e3a34c738b256))
* implement models for extra files ([#6](https://www.github.com/bihealth/clinvar-this/issues/6)) ([#13](https://www.github.com/bihealth/clinvar-this/issues/13)) ([852e4c6](https://www.github.com/bihealth/clinvar-this/commit/852e4c6cd981ae533afbfda0217a4b9e1de8065e))
* implement models for submission message ([#8](https://www.github.com/bihealth/clinvar-this/issues/8)) ([#15](https://www.github.com/bihealth/clinvar-this/issues/15)) ([90afd10](https://www.github.com/bihealth/clinvar-this/commit/90afd105fc0d29c3962529157f38a20e48090a56))
* implement more columns in TSV ([#39](https://www.github.com/bihealth/clinvar-this/issues/39)) ([#55](https://www.github.com/bihealth/clinvar-this/issues/55)) ([6184d76](https://www.github.com/bihealth/clinvar-this/commit/6184d76a2f8261131718bbe69e88fdaf66b3a8de))
* implementing REST clinvar_api.client module ([#28](https://www.github.com/bihealth/clinvar-this/issues/28)) ([#29](https://www.github.com/bihealth/clinvar-this/issues/29)) ([829d907](https://www.github.com/bihealth/clinvar-this/commit/829d907763db617a04d277f297256980d25d51ab))
* store errors from "batch retrieve" ([#59](https://www.github.com/bihealth/clinvar-this/issues/59)) ([#60](https://www.github.com/bihealth/clinvar-this/issues/60)) ([67b8b0c](https://www.github.com/bihealth/clinvar-this/commit/67b8b0ccd85d4a913e7b8f1eb30dc4e96a2af32c))
* write data into profile sub directory ([#52](https://www.github.com/bihealth/clinvar-this/issues/52)) ([e699736](https://www.github.com/bihealth/clinvar-this/commit/e6997367d77586c1337a44fa7b5306ecede52a41))


### Bug Fixes

* interpret TSV OMIM "not provided" ([#57](https://www.github.com/bihealth/clinvar-this/issues/57)) ([#58](https://www.github.com/bihealth/clinvar-this/issues/58)) ([b655097](https://www.github.com/bihealth/clinvar-this/commit/b655097f2bf534b57115e3f9f5d18387ddfb1f18))


### Documentation

* add getting started tutorial to README ([#45](https://www.github.com/bihealth/clinvar-this/issues/45)) ([#61](https://www.github.com/bihealth/clinvar-this/issues/61)) ([3de084b](https://www.github.com/bihealth/clinvar-this/commit/3de084b49c184dfc6fb977b64cf478f03275ef9b))
